==> tripetto-collector-0.4.23.tgz: package/README.md <==
![Tripetto](https://docs.tripetto.community/assets/header.svg)

Tripetto is a full-fledged form kit. Rapidly create and deploy smart flowing forms and surveys. Drop the kit in your codebase and use all of it, or just the parts you need. The visual [**editor**](https://www.npmjs.com/package/tripetto) is for form creation, the [**collector**](https://www.npmjs.com/package/tripetto-collector) for response collection and the [**SDK**](https://docs.tripetto.community/blocks) for developing more form building blocks.

# Collector package
[![Version](https://img.shields.io/npm/v/tripetto-collector.svg)](https://www.npmjs.com/package/tripetto-collector)
[![License](https://img.shields.io/npm/l/tripetto-collector.svg)](https://opensource.org/licenses/MIT)
[![Downloads](https://img.shields.io/npm/dt/tripetto-collector.svg)](https://www.npmjs.com/package/tripetto-collector)
[![Read the docs](https://img.shields.io/badge/docs-website-blue.svg)](https://docs.tripetto.community/collector)
[![Join the community on Spectrum](https://withspectrum.github.io/badge/badge.svg)](https://spectrum.chat/tripetto)
[![Follow us on Twitter](https://img.shields.io/twitter/follow/tripetto.svg?style=social&label=Follow)](https://twitter.com/tripetto)

The collector is a 2-in-1 package with:
- A library to handily embed forms in websites and applications - [Docs](https://docs.tripetto.community/collector/) - [Examples](#examples)
- Typings to implement the library using TypeScript - [Tutorials](#tutorials)

# Purpose
You use the supplementary collector library to handily deploy smart forms in websites and applications. It turns a [form definition](https://docs.tripetto.community/editor/#definitions) (created with the graphical [editor](https://www.npmjs.com/package/tripetto)) into an executable program; a finite state machine that handles all the complex logic and response collection during the execution of the form. The collector also supports pausing and resuming. Apply any UI framework you like. Or pick from the out-of-the-box implementations for [React](https://gitlab.com/tripetto/examples/react), [Angular](https://gitlab.com/tripetto/examples/angular) or [plain JS](https://gitlab.com/tripetto/examples/plain).

# Demo
[![Try the demo](https://docs.tripetto.community/images/demo.svg)](https://codepen.io/tripetto/project/full/AbbmLR/)
[![View the code](https://docs.tripetto.community/images/codepen.svg)](https://codepen.io/tripetto/project/editor/AbbmLR)

# Get started
To use the library in your project you should install the collector package as a dependency using the following command:
```bash
$ npm install tripetto-collector --save
```

# Examples
- https://gitlab.com/tripetto/examples/react
- https://gitlab.com/tripetto/examples/react-material-ui
- https://gitlab.com/tripetto/examples/angular
- https://gitlab.com/tripetto/examples/bootstrap
- https://gitlab.com/tripetto/examples/plain

# Tutorials
- https://medium.com/tripetto/implementing-tripetto-forms-using-react-f4f2a04ee380

# Documentation
The complete documentation can be found at [docs.tripetto.community](https://docs.tripetto.community).

Detailed **collector** documentation is available [here](https://docs.tripetto.community/collector/).

More about the **editor** is found [here](https://docs.tripetto.community/editor/).

If you want to develop your own building **blocks**, read more [here](https://docs.tripetto.community/blocks/) or start with our [boilerplate](https://gitlab.com/tripetto/blocks/boilerplate).

# Support
Run into issues or bugs? Report them [here](https://gitlab.com/tripetto/collector/issues) and we'll look into them.

For general support contact us at [support@tripetto.com](mailto:support@tripetto.com). We're more than happy to assist you.

# License
Have a blast. [MIT](https://opensource.org/licenses/MIT).

# Community
We hope other enthusiasts will also start to develop and share collectors and blocks for Tripetto. We have a [repository](https://github.com/tripetto/community) where we collect a list of community driven blocks and collectors. Did you build something? Submit a [PR](https://github.com/tripetto/community/pulls) and add yours to the list. We appreciate it!

# About us
If you want to learn more about Tripetto or contribute in any way, visit us at [Tripetto.com](https://tripetto.com/).

==> tripetto-collector-0.4.26-26.tgz: package/README.md <==
![Tripetto](https://docs.tripetto.community/assets/header.svg)

Tripetto is a full-fledged form kit. Rapidly create and deploy smart flowing forms and surveys. Drop the kit in your codebase and use all of it, or just the parts you need. The visual [**editor**](https://www.npmjs.com/package/tripetto) is for form creation, the [**collector**](https://www.npmjs.com/package/tripetto-collector) for response collection and the [**SDK**](https://docs.tripetto.community/blocks) for developing more form building blocks.

# Collector package
[![Version](https://img.shields.io/npm/v/tripetto-collector.svg)](https://www.npmjs.com/package/tripetto-collector)
[![License](https://img.shields.io/npm/l/tripetto-collector.svg)](https://opensource.org/licenses/MIT)
[![Downloads](https://img.shields.io/npm/dt/tripetto-collector.svg)](https://www.npmjs.com/package/tripetto-collector)
[![Read the docs](https://img.shields.io/badge/docs-website-blue.svg)](https://docs.tripetto.community/collector)
[![Join the community on Spectrum](https://withspectrum.github.io/badge/badge.svg)](https://spectrum.chat/tripetto)
[![Follow us on Twitter](https://img.shields.io/twitter/follow/tripetto.svg?style=social&label=Follow)](https://twitter.com/tripetto)

The collector is a 2-in-1 package with:
- A library to handily embed forms in websites and applications - [Docs](https://docs.tripetto.community/collector/) - [Examples](#examples)
- Typings to implement the library using TypeScript - [Tutorials](#tutorials)

# Purpose
You use the collector library to handily deploy smart forms in websites and applications. It turns a [form definition](https://docs.tripetto.community/editor/#definitions) (created with the graphical [editor](https://www.npmjs.com/package/tripetto)) into an executable program; a finite state machine that handles all the complex logic and response collection during the execution of the form. The collector also supports pausing and resuming. Apply any UI framework you like. Or pick from the out-of-the-box implementations for [React](https://gitlab.com/tripetto/examples/react), [Angular](https://gitlab.com/tripetto/examples/angular) or [plain JS](https://gitlab.com/tripetto/examples/plain).

# Demo
[![Try the demo](https://docs.tripetto.community/images/demo.svg)](https://codepen.io/tripetto/project/full/AbbmLR/)
[![View the code](https://docs.tripetto.community/images/codepen.svg)](https://codepen.io/tripetto/project/editor/AbbmLR)

# Get started
To use the library in your project you should install the collector package as a dependency using the following command:
```bash
$ npm install tripetto-collector --save
```

# Examples
- https://gitlab.com/tripetto/examples/react
- https://gitlab.com/tripetto/examples/react-material-ui
- https://gitlab.com/tripetto/examples/angular
- https://gitlab.com/tripetto/examples/bootstrap
- https://gitlab.com/tripetto/examples/plain

# Tutorials
- https://medium.com/tripetto/implementing-tripetto-forms-using-react-f4f2a04ee380

# Documentation
The complete documentation can be found at [docs.tripetto.community](https://docs.tripetto.community).

Detailed **collector** documentation is available [here](https://docs.tripetto.community/collector/).

More about the **editor** is found [here](https://docs.tripetto.community/editor/).

If you want to develop your own building **blocks**, read more [here](https://docs.tripetto.community/blocks/) or start with our [boilerplate](https://gitlab.com/tripetto/blocks/boilerplate).

# Support
Run into issues or bugs? Report them [here](https://gitlab.com/tripetto/collector/issues) and we'll look into them.

For general support contact us at [support@tripetto.com](mailto:support@tripetto.com). We're more than happy to assist you.

# License
Have a blast. [MIT](https://opensource.org/licenses/MIT).

# Community
We hope other enthusiasts will also start to develop and share collectors and blocks for Tripetto. We have a [repository](https://github.com/tripetto/community) where we collect a list of community driven blocks and collectors. Did you build something? Submit a [PR](https://github.com/tripetto/community/pulls) and add yours to the list. We appreciate it!

# About us
If you want to learn more about Tripetto or contribute in any way, visit us at [Tripetto.com](https://tripetto.com/).
